==> better-admin-ui-vue-0.0.2.tgz: package/es/components/PageHeader/PageHeader.js <==
import * as _vue from "vue";
import { PageHeaderProps } from './types';
import './style.less';
import AAvatar from 'ant-design-vue/es/avatar';
/**
 * 业务页面的头部。可配置主标题、副标题、描述及操作按钮集
 */

export default {
  name: 'EPageHeader',
  props: PageHeaderProps,
  components: {
    AAvatar: AAvatar
  },
  methods: {
    /**
     * 渲染头部内容
     * @param h
     * @returns {JSX.Element}
     * @private
     */
    _renderHeaderContent: function _renderHeaderContent(h) {
      return _vue.createVNode("div", {
        "class": "main"
      }, [_vue.createVNode("div", {
        "class": "row"
      }, [this._renderLogo(), this._renderTitles(h), this._renderAction(h)]), _vue.createVNode("div", {
        "class": "row"
      }, [this._renderAvatar(), this._renderContentAndDescription(h), this._renderExtra(h)]), this.$slots.pageMenu ? h('div', [this.$slots.pageMenu]) : null]);
    },

    /**
     * 渲染logo
     * @returns {JSX.Element|null}
     * @private
     */
    _renderLogo: function _renderLogo() {
      if (this.$props.logo) {
        return _vue.createVNode("img", {
          "src": this.$props.logo,
          "class": "logo"
        }, null);
      } else {
        return null;
      }
    },

    /**
     * 渲染主标题和副标题
     * @param h
     * @returns {JSX.Element|*}
     * @private
     */
    _renderTitles: function _renderTitles(h) {
      if (this.$slots.title) {
        return h('div', {
          "class": ['title']
        }, [this.$slots.title]);
      } else {
        var _this$$props = this.$props,
            title = _this$$props.title,
            subTitle = _this$$props.subTitle;

        if (title) {
          return _vue.createVNode("h1", {
            "class": "title"
          }, [title, subTitle ? _vue.createVNode("span", {
            "class": "sub-title"
          }, [subTitle]) : null]);
        }
      }
    },

    /**
     * 渲染按钮操作集
     * @param h
     * @returns {*|null}
     * @private
     */
    _renderAction: function _renderAction(h) {
      return this.$slots.action ? h('div', {
        "class": ['action']
      }, [this.$slots.action]) : null;
    },

    /**
     * 渲染头像
     * @returns {JSX.Element|null}
     * @private
     */
    _renderAvatar: function _renderAvatar() {
      if (this.$props.avatar) {
        return _vue.createVNode("div", {
          "class": "avatar"
        }, [_vue.createVNode(_vue.resolveComponent("a-avatar"), {
          "src": this.$props.avatar
        }, null)]);
      } else {
        return null;
      }
    },

    /**
     * 渲染内容和描述部分
     * @param h
     * @returns {JSX.Element|null|*}
     * @private
     */
    _renderContentAndDescription: function _renderContentAndDescription(h) {
      if (this.$slots.content) {
        return h('div', {
          "class": ['headerContent']
        }, [this.$slots.content]);
      } else {
        if (this.$props.description) {
          return _vue.createVNode("p", {
            "style": "font-size: 14px;color: rgba(0,0,0,.65)"
          }, [this.$props.description]);
        } else {
          return null;
        }
      }
    },

    /**
     * 渲染额外的部分
     * @param h
     * @returns {*|null}
     * @private
     */
    _renderExtra: function _renderExtra(h) {
      return this.$slots.extra ? h('div', {
        "class": ['extra']
      }, [this.$slots.extra]) : null;
    }
  },
  render: function render(h) {
    return _vue.createVNode("div", {
      "class": "page-header"
    }, [_vue.createVNode("div", {
      "class": "page-header-index-wide"
    }, [_vue.createVNode("div", {
      "class": "detail"
    }, [this.$route.meta.hiddenHeaderContent ? null : this._renderHeaderContent(h)])])]);
  }
};

==> better-admin-ui-vue-0.0.26.tgz: package/es/components/PageHeader/PageHeader.js <==
import { PageHeaderProps } from './types';
import './style.less';
import AAvatar from 'ant-design-vue/es/avatar';
/**
 * 业务页面的头部。可配置主标题、副标题、描述及操作按钮集
 */

export default {
  name: 'EPageHeader',
  props: PageHeaderProps,
  methods: {
    /**
     * 渲染头部内容
     * @param h
     * @returns {JSX.Element}
     * @private
     */
    _renderHeaderContent: function _renderHeaderContent(h) {
      return h("div", {
        "class": "main"
      }, [h("div", {
        "class": "row"
      }, [this._renderLogo(), this._renderTitles(h), this._renderAction(h)]), h("div", {
        "class": "row"
      }, [this._renderAvatar(), this._renderContentAndDescription(h), this._renderExtra(h)]), this.$slots.pageMenu ? h('div', [this.$slots.pageMenu]) : null]);
    },

    /**
     * 渲染logo
     * @returns {JSX.Element|null}
     * @private
     */
    _renderLogo: function _renderLogo() {
      var h = this.$createElement;

      if (this.$props.logo) {
        return h("img", {
          attrs: {
            src: this.$props.logo
          },
          "class": "logo"
        });
      } else {
        return null;
      }
    },

    /**
     * 渲染主标题和副标题
     * @param h
     * @returns {JSX.Element|*}
     * @private
     */
    _renderTitles: function _renderTitles(h) {
      if (this.$slots.title) {
        return h('div', {
          "class": ['title']
        }, [this.$slots.title]);
      } else {
        var _this$$props = this.$props,
            title = _this$$props.title,
            subTitle = _this$$props.subTitle;

        if (title) {
          return h("h1", {
            "class": "title"
          }, [title, subTitle ? h("span", {
            "class": "sub-title"
          }, [subTitle]) : null]);
        }
      }
    },

    /**
     * 渲染按钮操作集
     * @param h
     * @returns {*|null}
     * @private
     */
    _renderAction: function _renderAction(h) {
      return this.$slots.action ? h('div', {
        "class": ['action']
      }, [this.$slots.action]) : null;
    },

    /**
     * 渲染头像
     * @returns {JSX.Element|null}
     * @private
     */
    _renderAvatar: function _renderAvatar() {
      var h = this.$createElement;

      if (this.$props.avatar) {
        return h("div", {
          "class": "avatar"
        }, [h(AAvatar, {
          attrs: {
            src: this.$props.avatar
          }
        })]);
      } else {
        return null;
      }
    },

    /**
     * 渲染内容和描述部分
     * @param h
     * @returns {JSX.Element|null|*}
     * @private
     */
    _renderContentAndDescription: function _renderContentAndDescription(h) {
      if (this.$slots.content) {
        return h('div', {
          "class": ['headerContent']
        }, [this.$slots.content]);
      } else {
        if (this.$props.description) {
          return h("p", {
            style: "font-size: 14px;color: rgba(0,0,0,.65)"
          }, [this.$props.description]);
        } else {
          return null;
        }
      }
    },

    /**
     * 渲染额外的部分
     * @param h
     * @returns {*|null}
     * @private
     */
    _renderExtra: function _renderExtra(h) {
      return this.$slots.extra ? h('div', {
        "class": ['extra']
      }, [this.$slots.extra]) : null;
    }
  },
  render: function render(h) {
    return h("div", {
      "class": "page-header"
    }, [h("div", {
      "class": "page-header-index-wide"
    }, [h("div", {
      "class": "detail"
    }, [this.$route.meta.hiddenHeaderContent ? null : this._renderHeaderContent(h)])])]);
  }
};
